@@ -7,6 +7,16 @@ use std::io::{Cursor, Error};
 
 const DEFAULT_COMPRESSION_LEVEL: u32 = 6;
 
+pub const ZLIB_MIN_HEADER_SIZE: usize = 2;
+pub const ZLIB_FOOTER_SIZE: usize = 4;
+pub const ZLIB_MIN_OVERHEAD: usize = ZLIB_MIN_HEADER_SIZE + ZLIB_FOOTER_SIZE;
+
+/// Compression upper bound
+// xref: https://github.com/ebiggers/libdeflate/blob/6bb493615b0ef35c98fc4aa4ec04f448788db6a5/lib/zlib_compress.c#L77
+pub fn compress_bound(len: usize) -> usize {
+    ZLIB_MIN_OVERHEAD + crate::deflate::compress_bound(len)
+}
+
 /// Decompress zlib data
 #[inline(always)]
 pub fn decompress<W: Write + ?Sized, R: Read>(input: R, output: &mut W) -> Result<usize, Error> {
